---
title: <span class="badge object-type-enum"></span> MapCenterID
---
# <span class="badge object-type-enum"></span> MapCenterID

## Definition

```python
class MapCenterID(enum.StrEnum):
    ZERO = "zero"
    COORDS = "coords"
    FIT = "fit"
```
